==> zio-aws-config_3-5.17.158.3-sources.jar: zio/aws/config/model/ExternalEvaluation.scala <==
package zio.aws.config.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.config.model.primitives.{
  OrderingTimestamp,
  BaseResourceId,
  StringWithCharLimit256
}
import java.time.Instant
import scala.jdk.CollectionConverters.*
final case class ExternalEvaluation(
    complianceResourceType: StringWithCharLimit256,
    complianceResourceId: BaseResourceId,
    complianceType: zio.aws.config.model.ComplianceType,
    annotation: Option[StringWithCharLimit256] = None,
    orderingTimestamp: OrderingTimestamp
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.config.model.ExternalEvaluation = {
    import ExternalEvaluation.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.config.model.ExternalEvaluation
      .builder()
      .complianceResourceType(
        StringWithCharLimit256.unwrap(complianceResourceType): java.lang.String
      )
      .complianceResourceId(
        BaseResourceId.unwrap(complianceResourceId): java.lang.String
      )
      .complianceType(complianceType.unwrap)
      .optionallyWith(
        annotation.map(value =>
          StringWithCharLimit256.unwrap(value): java.lang.String
        )
      )(_.annotation)
      .orderingTimestamp(OrderingTimestamp.unwrap(orderingTimestamp): Instant)
      .build()
  }
  def asReadOnly: zio.aws.config.model.ExternalEvaluation.ReadOnly =
    zio.aws.config.model.ExternalEvaluation.wrap(buildAwsValue())
}
object ExternalEvaluation {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.config.model.ExternalEvaluation
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.config.model.ExternalEvaluation =
      zio.aws.config.model.ExternalEvaluation(
        complianceResourceType,
        complianceResourceId,
        complianceType,
        annotation.map(value => value),
        orderingTimestamp
      )
    def complianceResourceType: StringWithCharLimit256
    def complianceResourceId: BaseResourceId
    def complianceType: zio.aws.config.model.ComplianceType
    def annotation: Option[StringWithCharLimit256]
    def orderingTimestamp: OrderingTimestamp
    def getComplianceResourceType: ZIO[Any, Nothing, StringWithCharLimit256] =
      ZIO.succeed(complianceResourceType)
    def getComplianceResourceId: ZIO[Any, Nothing, BaseResourceId] =
      ZIO.succeed(complianceResourceId)
    def getComplianceType
        : ZIO[Any, Nothing, zio.aws.config.model.ComplianceType] =
      ZIO.succeed(complianceType)
    def getAnnotation: ZIO[Any, AwsError, StringWithCharLimit256] =
      AwsError.unwrapOptionField("annotation", annotation)
    def getOrderingTimestamp: ZIO[Any, Nothing, OrderingTimestamp] =
      ZIO.succeed(orderingTimestamp)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.config.model.ExternalEvaluation
  ) extends zio.aws.config.model.ExternalEvaluation.ReadOnly {
    override val complianceResourceType: StringWithCharLimit256 =
      zio.aws.config.model.primitives
        .StringWithCharLimit256(impl.complianceResourceType())
    override val complianceResourceId: BaseResourceId =
      zio.aws.config.model.primitives
        .BaseResourceId(impl.complianceResourceId())
    override val complianceType: zio.aws.config.model.ComplianceType =
      zio.aws.config.model.ComplianceType.wrap(impl.complianceType())
    override val annotation: Option[StringWithCharLimit256] = scala
      .Option(impl.annotation())
      .map(value =>
        zio.aws.config.model.primitives.StringWithCharLimit256(value)
      )
    override val orderingTimestamp: OrderingTimestamp =
      zio.aws.config.model.primitives
        .OrderingTimestamp(impl.orderingTimestamp())
  }
  def wrap(
      impl: software.amazon.awssdk.services.config.model.ExternalEvaluation
  ): zio.aws.config.model.ExternalEvaluation.ReadOnly = new Wrapper(impl)
}

==> zio-aws-config_3-7.21.15.2-sources.jar: zio/aws/config/model/ExternalEvaluation.scala <==
package zio.aws.config.model
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.config.model.primitives.{
  OrderingTimestamp,
  BaseResourceId,
  StringWithCharLimit256
}
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import scala.jdk.CollectionConverters.*
final case class ExternalEvaluation(
    complianceResourceType: StringWithCharLimit256,
    complianceResourceId: BaseResourceId,
    complianceType: zio.aws.config.model.ComplianceType,
    annotation: Optional[StringWithCharLimit256] = Optional.Absent,
    orderingTimestamp: OrderingTimestamp
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.config.model.ExternalEvaluation = {
    import ExternalEvaluation.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.config.model.ExternalEvaluation
      .builder()
      .complianceResourceType(
        StringWithCharLimit256.unwrap(complianceResourceType): java.lang.String
      )
      .complianceResourceId(
        BaseResourceId.unwrap(complianceResourceId): java.lang.String
      )
      .complianceType(complianceType.unwrap)
      .optionallyWith(
        annotation.map(value =>
          StringWithCharLimit256.unwrap(value): java.lang.String
        )
      )(_.annotation)
      .orderingTimestamp(OrderingTimestamp.unwrap(orderingTimestamp): Instant)
      .build()
  }
  def asReadOnly: zio.aws.config.model.ExternalEvaluation.ReadOnly =
    zio.aws.config.model.ExternalEvaluation.wrap(buildAwsValue())
}
object ExternalEvaluation {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.config.model.ExternalEvaluation
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.config.model.ExternalEvaluation =
      zio.aws.config.model.ExternalEvaluation(
        complianceResourceType,
        complianceResourceId,
        complianceType,
        annotation.map(value => value),
        orderingTimestamp
      )
    def complianceResourceType: StringWithCharLimit256
    def complianceResourceId: BaseResourceId
    def complianceType: zio.aws.config.model.ComplianceType
    def annotation: Optional[StringWithCharLimit256]
    def orderingTimestamp: OrderingTimestamp
    def getComplianceResourceType: ZIO[Any, Nothing, StringWithCharLimit256] =
      ZIO.succeed(complianceResourceType)
    def getComplianceResourceId: ZIO[Any, Nothing, BaseResourceId] =
      ZIO.succeed(complianceResourceId)
    def getComplianceType
        : ZIO[Any, Nothing, zio.aws.config.model.ComplianceType] =
      ZIO.succeed(complianceType)
    def getAnnotation: ZIO[Any, AwsError, StringWithCharLimit256] =
      AwsError.unwrapOptionField("annotation", annotation)
    def getOrderingTimestamp: ZIO[Any, Nothing, OrderingTimestamp] =
      ZIO.succeed(orderingTimestamp)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.config.model.ExternalEvaluation
  ) extends zio.aws.config.model.ExternalEvaluation.ReadOnly {
    override val complianceResourceType: StringWithCharLimit256 =
      zio.aws.config.model.primitives
        .StringWithCharLimit256(impl.complianceResourceType())
    override val complianceResourceId: BaseResourceId =
      zio.aws.config.model.primitives
        .BaseResourceId(impl.complianceResourceId())
    override val complianceType: zio.aws.config.model.ComplianceType =
      zio.aws.config.model.ComplianceType.wrap(impl.complianceType())
    override val annotation: Optional[StringWithCharLimit256] =
      zio.aws.core.internal
        .optionalFromNullable(impl.annotation())
        .map(value =>
          zio.aws.config.model.primitives.StringWithCharLimit256(value)
        )
    override val orderingTimestamp: OrderingTimestamp =
      zio.aws.config.model.primitives
        .OrderingTimestamp(impl.orderingTimestamp())
  }
  def wrap(
      impl: software.amazon.awssdk.services.config.model.ExternalEvaluation
  ): zio.aws.config.model.ExternalEvaluation.ReadOnly = new Wrapper(impl)
}
